1.0.0 API documentation: GLM_EXT_vector_float1_precision

| 1.0.0 API documentation

Typedefs
GLM_EXT_vector_float1_precision
Stable extensions

## Typedefs
typedef vec< 1, float, highp > | highp_vec1
| 1 component vector of single-precision floating-point numbers using high precision arithmetic in term of ULPs.
typedef vec< 1, float, lowp > | lowp_vec1
| 1 component vector of single-precision floating-point numbers using low precision arithmetic in term of ULPs.
typedef vec< 1, float, mediump > | mediump_vec1
| 1 component vector of single-precision floating-point numbers using medium precision arithmetic in term of ULPs.

## Detailed Description

Exposes highp_vec1, mediump_vec1 and lowp_vec1 types.

Include <glm/ext/vector_float1_precision.hpp> to use the features of this extension.

See also
  GLM_EXT_vector_float1 extension.